{% if pacemaker_running %}
@{{ current_vip.name }}vip @overcloud{{ current_vip.name }}cluster : PSK "{{ ipsec_psk }}"
{% endif %}
@overcloud{{ current_vip.name }}cluster @{{ current_vip.name }}vip : PSK "{{ ipsec_psk }}"
