{% if pacemaker_running %}
{% for controller_unsplit in controllers %}
{% set controller = controller_unsplit.split(',') %}
{% if controller[0] != (ansible_hostname + '.' + network) %}
@{{ ansible_hostname }}.{{ network }} @{{ controller[0] }} : PSK "{{ ipsec_psk }}"
{% endif %}
{% endfor %}
@{{ ansible_hostname }}.{{ network }} @computecluster : PSK "{{ ipsec_psk }}"
{% else %}
{% for controller_unsplit in controllers %}
{% set controller = controller_unsplit.split(',') %}
@computecluster @{{ controller[0] }} : PSK "{{ ipsec_psk }}"
{% endfor %}
{% endif %}
